@@ -29,54 +29,60 @@ INTERNALERROR_CREATESERVICEERROR = 'InternalError.CreateServiceError'
 # The server is busy. Retry later.
 INTERNALERROR_DEFAULTINTERNALERROR = 'InternalError.DefaultInternalError'
 
-# Failed to delete the application
-INTERNALERROR_DELETESERVICEERROR = 'InternalError.DeleteServiceError'
-
 # Failed to invoke the version deployment
 INTERNALERROR_DEPLOYVERSIONERROR = 'InternalError.DeployVersionError'
 
 # Failed to query the instance information
 INTERNALERROR_DESCRIBERUNPODLISTERROR = 'InternalError.DescribeRunPodListError'
 
+# Failed to query the list of ingress associated with the service.
+INTERNALERROR_DESCRIBESERVICEINGRESSERROR = 'InternalError.DescribeServiceIngressError'
+
 # Failed to restart
 INTERNALERROR_RESTARTAPPLICATIONERROR = 'InternalError.RestartApplicationError'
 
 # Failed to update the ingress
 INTERNALERROR_UPDATEINGRESSERROR = 'InternalError.UpdateIngressError'
 
+# 
+INVALIDPARAMETERVALUE_AUTOSCALERLARGERTHANONE = 'InvalidParameterValue.AutoScalerLargerThanOne'
+
 # The version number is invalid.
 INVALIDPARAMETERVALUE_INVALIDDEPLOYVERSION = 'InvalidParameterValue.InvalidDeployVersion'
 
 # The environment already exists.
 INVALIDPARAMETERVALUE_NAMESPACEDUPLICATEERROR = 'InvalidParameterValue.NamespaceDuplicateError'
 
+# The namespace does not belong to the current account.
+INVALIDPARAMETERVALUE_NAMESPACENOTBELONGTOAPPID = 'InvalidParameterValue.NamespaceNotBelongToAppid'
+
 # Failed to create the environment. The upper limit of environment is reached.
 INVALIDPARAMETERVALUE_NAMESPACEREACHMAXIMUM = 'InvalidParameterValue.NamespaceReachMaximum'
 
 # Failed to create the environment. The upper limit of environment is reached.
 INVALIDPARAMETERVALUE_NAMESPACERESOURCEREACHMAXIMUM = 'InvalidParameterValue.NamespaceResourceReachMaximum'
 
-# There are running pods in this application.
-INVALIDPARAMETERVALUE_SERVICEFOUNDRUNNINGVERSION = 'InvalidParameterValue.ServiceFoundRunningVersion'
-
-# This application name already exists.
-INVALIDPARAMETERVALUE_SERVICENAMEDUPLICATEERROR = 'InvalidParameterValue.ServiceNameDuplicateError'
-
 # Linkage tracing is not available for non-JAVA applications.
 INVALIDPARAMETERVALUE_TRAITSTRACINGNOTSUPPORTED = 'InvalidParameterValue.TraitsTracingNotSupported'
 
 # The version must be in lower case.
 INVALIDPARAMETERVALUE_VERSIONLOWERCASE = 'InvalidParameterValue.VersionLowerCase'
 
-# There is still traffic routed to this version.
-INVALIDPARAMETERVALUE_VERSIONROUTERATENOTZERO = 'InvalidParameterValue.VersionRouteRateNotZero'
-
-# 
+# The deployment version cannot be empty.
 MISSINGPARAMETER_DEPLOYVERSIONNULL = 'MissingParameter.DeployVersionNull'
 
 # The environment ID can not be left empty.
 MISSINGPARAMETER_NAMESPACEIDNULL = 'MissingParameter.NamespaceIdNull'
 
+# 
+MISSINGPARAMETER_PKGNAMENULL = 'MissingParameter.PkgNameNull'
+
+# The service ID cannot be empty.
+MISSINGPARAMETER_SERVICEIDNULL = 'MissingParameter.ServiceIdNull'
+
+# This resource is already bound.
+RESOURCEINUSE_RESOURCEALREADYUSED = 'ResourceInUse.ResourceAlreadyUsed'
+
 # The target microservice is offline.
 RESOURCENOTFOUND_MICROSERVICEOFFLINE = 'ResourceNotFound.MicroserviceOffline'
 
@@ -92,11 +98,5 @@ RESOURCENOTFOUND_SERVICERUNNINGVERSIONNOTFOUND = 'ResourceNotFound.ServiceRunnin
 # The environment corresponding to this version is not found.
 RESOURCENOTFOUND_VERSIONNAMESPACENOTFOUND = 'ResourceNotFound.VersionNamespaceNotFound'
 
-# The environment corresponding to this version is not found.
-RESOURCENOTFOUND_VERSIONSERVICENOTFOUND = 'ResourceNotFound.VersionServiceNotFound'
-
 # Waiting for the installation of addon
 RESOURCEUNAVAILABLE_WAITFORKRUISE = 'ResourceUnavailable.WaitForKruise'
-
-# Unauthorized
-UNAUTHORIZEDOPERATION_UNAUTHORIZEDOPERATION = 'UnauthorizedOperation.UnauthorizedOperation'
